==> 1.3.13.tar.gz: doc/User.md <==
# vrchat_dart_generated.model.User

## Load the model package
```dart
import 'package:vrchat_dart_generated/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **String** |  | 
**username** | **String** |  | 
**displayName** | **String** |  | 
**userIcon** | **String** |  | 
**bio** | **String** |  | 
**bioLinks** | **BuiltList&lt;String&gt;** |  | 
**profilePicOverride** | **String** |  | 
**statusDescription** | **String** |  | 
**currentAvatarImageUrl** | **String** |  | 
**currentAvatarThumbnailImageUrl** | **String** |  | 
**fallbackAvatar** | **String** |  | 
**state** | [**UserState**](UserState.md) |  | 
**tags** | **BuiltList&lt;String&gt;** |  | 
**developerType** | [**DeveloperType**](DeveloperType.md) |  | 
**lastLogin** | **String** |  | 
**lastPlatform** | **String** | This can be `standalonewindows` or `android`, but can also pretty much be any random Unity verison such as `2019.2.4-801-Release` or `2019.2.2-772-Release` or even `unknownplatform`. | 
**allowAvatarCopying** | **bool** |  | 
**status** | [**UserStatus**](UserStatus.md) |  | 
**dateJoined** | [**Date**](Date.md) |  | 
**isFriend** | **bool** |  | 
**friendKey** | **String** |  | 
**worldId** | **String** |  | 
**instanceId** | **String** |  | 
**location** | **String** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> 1.5.3.tar.gz: doc/User.md <==
# vrchat_dart_generated.model.User

## Load the model package
```dart
import 'package:vrchat_dart_generated/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**allowAvatarCopying** | **bool** |  | 
**bio** | **String** |  | 
**bioLinks** | **BuiltList&lt;String&gt;** |  | 
**currentAvatarImageUrl** | **String** | When profilePicOverride is not empty, use it instead. | 
**currentAvatarThumbnailImageUrl** | **String** | When profilePicOverride is not empty, use it instead. | 
**dateJoined** | [**Date**](Date.md) |  | 
**developerType** | [**DeveloperType**](DeveloperType.md) |  | 
**displayName** | **String** |  | 
**friendKey** | **String** |  | 
**id** | **String** |  | 
**instanceId** | **String** |  | [optional] 
**isFriend** | **bool** |  | 
**lastLogin** | **String** |  | 
**lastPlatform** | **String** | This can be `standalonewindows` or `android`, but can also pretty much be any random Unity verison such as `2019.2.4-801-Release` or `2019.2.2-772-Release` or even `unknownplatform`. | 
**location** | **String** |  | [optional] 
**profilePicOverride** | **String** |  | 
**state** | [**UserState**](UserState.md) |  | 
**status** | [**UserStatus**](UserStatus.md) |  | 
**statusDescription** | **String** |  | 
**tags** | **BuiltList&lt;String&gt;** |  | 
**userIcon** | **String** |  | 
**username** | **String** |  | 
**worldId** | **String** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
